@@ -20,24 +20,23 @@
 
 
 ### Get MPI options.
-.mpiopt_get <- function(main, sub = NULL, envir = .GlobalEnv){
-  if(!is.null(sub)){
-    envir$.pbd_env[[main]][[sub]]
-  } else{
-    envir$.pbd_env[[main]]
-  }
-} # End of .mpiopt_get().
+# .mpiopt_get <- function(main, sub = NULL, envir = .GlobalEnv){
+#   if(!is.null(sub)){
+#     envir$.pbd_env[[main]][[sub]]
+#   } else{
+#     envir$.pbd_env[[main]]
+#   }
+# } # End of .mpiopt_get().
 
 ### Set MPI options.
-.mpiopt_set <- function(val, main, sub = NULL, envir = .GlobalEnv){
-  if(!is.null(sub)){
-    envir$.pbd_env[[main]][[sub]] <- val
-  } else{
-    envir$.pbd_env[[main]] <- val
-  }
-
-  invisible()
-} # End of .mpiopt_set().
+# .mpiopt_set <- function(val, main, sub = NULL, envir = .GlobalEnv){
+#   if(!is.null(sub)){
+#     envir$.pbd_env[[main]][[sub]] <- val
+#   } else{
+#     envir$.pbd_env[[main]] <- val
+#   }
+#   invisible()
+# } # End of .mpiopt_set().
 
 ### Initial MPI options.
 .mpiopt_init <- function(envir = .GlobalEnv){
